#

##

##

##

##

##

##

##

    	protocols

    	objectives

    		[ ] prevent all outbound traffic

    				table inet filter {
    					chain output {
    						type filter hook output priority 0;
    						policy drop;
    					}
    				}

    	kinds
    		HTTP
    			#
    			#	permit:
    			#		TCP (thusly HTTP) on 80
    			#
    			tcp dport 80 accept

    		HTTPS
    			#
    			#	permit:
    			#		TCP (thusly HTTPs) on 443
    			#
    			tcp dport 443 accept

    		SSH

    		TCP

    		UDP